@@ -1,3 +1,6 @@
+from deprecated.sphinx import deprecated
+
+
 DEFAULT_ROOT_DIR = "output"
 
 
@@ -193,10 +196,15 @@ def download_file(url, path):
 
 
 def remove_illegal_characters(content):
+    if content:
+        content = str(content)
+    else:
+        content = ""
     import re
     ILLEGAL_CHARACTERS_RE = re.compile(r'[\000-\010]|[\013-\014]|[\016-\037]|\xa0')
     content = ILLEGAL_CHARACTERS_RE.sub(r'', content)
     return content
+        
 
 
 @deprecated
@@ -344,6 +352,8 @@ def save_items_to_csv(items, path, head=None):
 
 
 
+
+
 def convert_csv_to_xlsx(csv_path, xlsx_path):
     import openpyxl
     wb = openpyxl.Workbook()
